@@ -156,7 +156,7 @@ where
             max = max * max;
             min = min * min;
             if max < min {
-                std::mem::swap(&mut min, &mut max);
+                core::mem::swap(&mut min, &mut max);
             }
 
             let diff = max - min;
@@ -206,7 +206,7 @@ where
         envelopes: &mut [T],
         selection_size: usize,
     ) {
-        ::pdqselect::select_by(envelopes, selection_size, |l, r| {
+        envelopes.select_nth_unstable_by(selection_size, |l, r| {
             l.envelope()
                 .lower
                 .nth(axis)
