@@ -1,4 +1,4 @@
-use std::mem::replace;
+use core::mem::replace;
 
 use crate::algorithm::selection_functions::SelectionFunction;
 use crate::node::{ParentNode, RTreeNode};
@@ -6,6 +6,11 @@ use crate::object::RTreeObject;
 use crate::params::RTreeParams;
 use crate::{Envelope, RTree};
 
+use alloc::{vec, vec::Vec};
+
+#[allow(unused_imports)] // Import is required when building without std
+use num_traits::Float;
+
 /// Iterator returned by `RTree::drain_*` methods.
 ///
 /// Draining iterator that removes elements of the tree selected by a
